import os
import re
import unittest

import bdi.sources.uta0

class UTA0_Base(object):

    def test_get_tx_exons(self):    
        tx_exons = self.uta0.get_tx_exons('NM_000551.3','GRCh37.p10')
        self.assertEqual( 3, len(tx_exons) )

    def test_get_tx_info(self):
        tx_info = self.uta0.get_tx_info('NM_000551.3')
        self.assertEqual( 213, tx_info['cds_start_i'] )

    def test_get_tx_seq(self):
        tsi = self.uta0.get_tx_seq('NM_000551.3')
        seq = tsi
        self.assertEqual( 4560, len(seq) )
        self.assertTrue( seq.startswith('cctcgcctccgttacaacgg') )
        self.assertTrue( seq.endswith('aaaggaaatag') )

    def test_get_tx_for_gene(self):
        tig = self.uta0.get_tx_for_gene('VHL')
        self.assertEqual( 2, len(tig) )

    def test_get_tx_exons_invalid_NM(self):
        tx_exons = self.uta0.get_tx_exons('NM_999999.9','GRCh37.p10')
        self.assertEqual( 0, len(tx_exons) )

    def test_get_tx_exons_invalid_ref(self):
        tx_exons = self.uta0.get_tx_exons('NM_000551.3','GRCh37.p1000')
        self.assertEqual( 0, len(tx_exons) )

    def test_get_tx_info_invalid_NM(self):
        tx_info = self.uta0.get_tx_info('NM_999999.9')
        self.assertIsNone( tx_info )

    def test_get_tx_seq_invalid_NM(self):
        tsi = self.uta0.get_tx_seq('NM_999999.9')
        self.assertIsNone( tsi )

    def test_get_tx_for_gene_invalid_gene(self):
        tig = self.uta0.get_tx_for_gene('GENE')
        self.assertEqual( 0, len(tig) )

    def test_get_ac_for_protein_seq(self):
        exp = [u'NP_001005405.1']
        s = """
        mgccgcsggc gsgcggcgsg sggcgsgcgg cgssccvpic cckpvcccvp acscsscgsc
        ggskggcgsc gsskggcgsc gcsqsncckp ccsssgcgsf ccqsscskpc ccqssccqss
        cckpcccqss ccqsscfkpc ccqssccvpv ccqcki
        """
        s = re.sub('\s+','',s.upper())
        self.assertEqual( sorted(self.uta0.get_ac_for_protein_seq(s)), sorted(exp) )
        
        exp = [u'XP_005248390.1',u'XP_005248391.1',u'XP_005248392.1',u'XP_005248393.1',u'NP_071928.2']
        s = """
        masetektha llqtcstesl isslglgafc lvadrllqfs tiqqndwlra lsdnavhcvi
        gmwswavvtg ikkktdfgei ilagflasvi dvdhfflags mslkaaltlp rrpflhcstv
        ipvvvltlkf tmhlfklkds wcflpwmlfi swtshhirdg irhglwicpf gktsplpfwl
        yviitsslph icsfvmyltg trqmmsskhg vridv
        """
        s = re.sub('\s+','',s.upper())
        self.assertEqual( sorted(self.uta0.get_ac_for_protein_seq(s)), sorted(exp) )


class Test_bdi_sources_uta0_UTA0_default(unittest.TestCase, UTA0_Base):
    def setUp(self):
        self.uta0 = bdi.sources.uta0.connect()
        return self


if __name__ == '__main__':
    unittest.main()
        

## <LICENSE>
## Copyright 2014 BDI Contributors (https://bitbucket.org/invitae/bdi)
## 
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
## 
##     http://www.apache.org/licenses/LICENSE-2.0
## 
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
## </LICENSE>
